@@ -1,6 +1,6 @@
 /*
 NNCP -- Node to Node copy, utilities for store-and-forward data exchange
-Copyright (C) 2016-2021 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2016-2022 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ import (
 	"os"
 	"path/filepath"
 	"sort"
+	"strconv"
 	"sync"
 	"time"
 
@@ -39,6 +40,7 @@ const (
 	MaxSPSize      = 1<<16 - 256
 	PartSuffix     = ".part"
 	SPHeadOverhead = 4
+	CfgDeadline    = "NNCPDEADLINE"
 )
 
 type MTHAndOffset struct {
@@ -132,6 +134,14 @@ type ConnDeadlined interface {
 }
 
 func init() {
+	if v := os.Getenv(CfgDeadline); v != "" {
+		i, err := strconv.Atoi(v)
+		if err != nil {
+			log.Fatalln("Can not convert", CfgDeadline, "to integer:", err)
+		}
+		DefaultDeadline = time.Duration(i) * time.Second
+	}
+
 	var buf bytes.Buffer
 	spHead := SPHead{Type: SPTypeHalt}
 	if _, err := xdr.Marshal(&buf, spHead); err != nil {
